---
title: <span class="badge object-type-scalar"></span> Yen
---
# <span class="badge object-type-scalar"></span> Yen

Currency: Yen (¥)

## Definition

```python
# Currency: Yen (¥)
Yen: typing.Literal["currencyJPY"] = "currencyJPY"
```
